function [t,x] = semidisc_simu(tau,r_sd,dim,init,tspan,mapcell)
% Runs a semidiscretization based simulation and gives the solution with
% the time step, that is applied in the semidiscretization. Therefore, the
% end of the solution's time interval may be different from the one that is
% given as the input. The output contains the initial function as well.
% tau: delay
% r_sd: sampling delay number
% dim: dimension of the system
% tspan: time interval
% mapcell: cell which contains the mapping matrices (generated by
% the semidiscmatr.m (or semidiscmatr_firstorder.m) function

T = tspan(2)-tspan(1);
dt = tau/(r_sd+1/2);  % time step
Nt = round(T/dt); 
z = zeros(dim*(r_sd+1),1);       % temporary variable for the mapping
x = zeros(dim,r_sd+Nt+1);        % state vector extended in time
% initial function
for i_IC = 1:r_sd+1
    if isa(init,'function_handle')
        z((i_IC-1)*dim+1:i_IC*dim,1) = init(tspan(1)-(i_IC-1)*dt);
        x(:,r_sd+2-i_IC) = init(tspan(1)-(i_IC-1)*dt);
    else
        z((i_IC-1)*dim+1:i_IC*dim,1) = init;
        x(:,r_sd+2-i_IC) = init;
    end        
end
% Run the map until the number of desired timesteps is reached
for it = 1 : Nt
    z = semidiscmap(z,dim,mapcell);       % semidiscretization map
    x(:,r_sd+it+1) = z(1:dim,1);          % save the state at each time step
end
t = tspan(1)+(-r_sd*dt:dt:Nt*dt);