function [t_interp,x_interp] = semidisc_simu_exact(tau,r_sd,dim,init,tspan,mapcell)
% Runs a semidiscretization based simulation and interpolates the solution
% within the exact time interval
% tau: delay
% r_sd: sampling delay number
% dim: dimension of the system
% tspan: time interval
% mapcell: cell which contains the mapping matrices (generated by
% the semidiscmatr.m (or semidiscmatr_firstorder.m) function

T = tspan(2)-tspan(1);
dt = tau/(r_sd+1/2);  % time step
Nt = ceil(T/dt); 
z = zeros(dim*(r_sd+1),1);       % temporary variable for the mapping
x = zeros(dim,Nt+1);        % state vector extended in time
% initial function
for i_IC = 1:r_sd+1
    if isa(init,'function_handle')
        z((i_IC-1)*dim+1:i_IC*dim,1) = init(tspan(1)-(i_IC-1)*dt);
    else
        z((i_IC-1)*dim+1:i_IC*dim,1) = init;
    end        
end
% Run the map until the number of desired timesteps is reached
x(:,1) = z(1:dim,1);
for it = 1 : Nt
    z = semidiscmap(z,dim,mapcell);       % semidiscretization map
    x(:,it+1) = z(1:dim,1);          % save the state at each time step
end
t = 0:dt:Nt*dt;
t_interp = linspace(0,T,Nt+1);
x_interp = interp1(t,x.',t_interp).';
